@@ -103,8 +103,8 @@ Michael Roberts, C<< <michael at vivtek.com> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-wx-definedui at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Wx-DefinedUI>.  I will be notified, and then you'll
+Please report any bugs or feature requests to C<bug-class-declarative at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Class-Declarative>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
 =head1 LICENSE AND COPYRIGHT
